# ManyAPI
All in one API wrapper written in Python.

## API list & Examples
- API List : [api_list.md](https://github.com/EterNomm/ManyAPI/blob/main/api_list.md)
- Examples : [examples](https://github.com/EterNomm/ManyAPI/tree/main/examples) directory

## Contribution
Can I add more API wrapper/fix some code? **Totally Allowed :)**

## Licence & Copyright
Copyright 2022-present EterNomm
```
GNU General Public License 3.0

A permissive license whose main conditions require preservation of copyright and license notices.
Contributors provide an express grant of patent rights.
Licensed works, modifications, and larger works may be distributed under different terms and without source code.
```
